/*
 * This file is part of buteo-syncfw package
 *
 * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: Sateesh Kavuri <sateesh.kavuri@nokia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */
#include "StoragePlugin.h"

using namespace Buteo;

StoragePlugin::StoragePlugin(const QString &aPluginName)
    : iPluginName(aPluginName)
{
}

StoragePlugin::~StoragePlugin()
{
}

const QString &StoragePlugin::getPluginName() const
{
    return iPluginName;
}

QString StoragePlugin::getProperty(const QString &aProperty) const
{
    QString returnValue = "";

    if (iProperties.contains(aProperty)) {
        returnValue = iProperties.value(aProperty);
    }
    return returnValue;
}

void StoragePlugin::getProperties(QMap<QString, QString> &aProperties) const
{
    aProperties = iProperties;
}
